#ifndef POKEPLATINUM_UNK_020562F8_H
#define POKEPLATINUM_UNK_020562F8_H

#include "struct_decls/struct_0203CDB0_decl.h"
#include "overlay006/battle_params.h"

void sub_020562F8(UnkStruct_0203CDB0 * param0);
void sub_02056328(UnkStruct_0203CDB0 * param0);
BOOL sub_02056374(UnkStruct_0203CDB0 * param0, int param1, int param2);
BattleParams * sub_0205639C(UnkStruct_0203CDB0 * param0);
void sub_020563AC(UnkStruct_0203CDB0 * param0, BattleParams * param1);
int sub_020563BC(UnkStruct_0203CDB0 * param0);
int sub_020563D0(UnkStruct_0203CDB0 * param0);
int sub_020563E0(UnkStruct_0203CDB0 * param0);
int sub_020563F0(UnkStruct_0203CDB0 * param0);

#endif // POKEPLATINUM_UNK_020562F8_H
